@@ -1,6 +1,6 @@
 #! /usr/bin/perl
 
-# $Id: lamdaemon.pl,v 1.3 2005/03/05 10:20:44 gruberroland Exp $
+# $Id: lamdaemon.pl,v 1.31 2005/10/07 16:07:07 gruberroland Exp $
 #
 #  This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
 #  Copyright (C) 2003  Tilo Lutz
@@ -102,21 +102,30 @@ if ($( == 0 ) { # we are root
 									system '/usr/sbin/useradd.local', $user[0]; # run useradd-script
 									}
 								}
+							else {
+								$return = "ERROR,Lamdaemon,Homedirectory already exists.:$return";
+								}
 							($<, $>) = ($>, $<); # Give up root previleges
 							last switch2;
 							};
 						$vals[2] eq 'rem' && do {
 							($<, $>) = ($>, $<); # Get root previliges
 							if (-d $user[7]) {
+								# Fixme, only delete files owned by user.
 								system 'rm', '-R', $user[7]; # Delete Homedirectory
 								if (-e '/usr/sbin/userdel.local') {
 									system '/usr/sbin/userdel.local', $user[0];
 									}
 								}
+							else {
+								$return = "ERROR,Lamdaemon,Homedirectory doesn't exists.:$return";
+								}
 							($<, $>) = ($>, $<); # Give up root previleges
 							last switch2;
 							};
 						}
+					# Show error if undfined command is used
+					$return = "ERROR,Lamdaemon,Unknown command $vals[2].:$return";
 					last switch;
 					};
 				$vals[1] eq 'quota' && do {
@@ -181,9 +190,11 @@ if ($( == 0 ) { # we are root
 							($<, $>) = ($>, $<); # Give up root previleges
 							last switch2;
 							};
+						$return = "ERROR,Lamdaemon,Unknown command $vals[2].:$return";
 						}
 					};
 					last switch;
+				$return = "ERROR,Lamdaemon,Unknown command $vals[1].:$return";
 				};
 				print "$return\n";
 			}
@@ -211,22 +222,24 @@ else {
 		$username = $username[0];
 		$password = $ARGV[1];
 	}
-	my $ssh = Net::SSH::Perl->new($hostname, options=>[
-		"UserKnownHostsFile /dev/null"],
-		protocol => "2,1" );
-	$ssh->login($username, $password);
 	# Put all transfered lines in one string
 	if ($ARGV[2] ne "*test") {
 		$string = do {local $/;<STDIN>};
-		@string2 = split ("\n", $string);
-		for ($i=0; $i<=$#string2; $i++) {
-			($stdout2, $stderr, $exit) = $ssh->cmd("sudo $remotepath $argv", $string2[$i]);
-			$stdout .= $stdout2;
 		}
-		print $stdout;
-	}
 	else {
-		($stdout, $stderr, $exit) = $ssh->cmd("sudo $remotepath *test");
-		print $stdout;
+		$argv = "*test\n";
+		$string = " \n";
+	}
+	my $ssh = Net::SSH::Perl->new($hostname, options=>[
+		"UserKnownHostsFile /dev/null"],
+		protocol => "2,1", debug => 0 );
+	$ssh->login($username, $password);
+	# Change needed to prevent buffer overrun
+	@string2 = split ("\n", $string);
+	for ($i=0; $i<=$#string2; $i++) {
+		($stdout2, $stderr, $exit) = $ssh->cmd("sudo $remotepath $argv", $string2[$i]);
+		$stdout .= $stdout2;
+		}
+	#($stdout, $stderr, $exit) = $ssh->cmd("sudo $remotepath $argv", $string);
+	print $stdout;
 	}
-}
