@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: conflogin.php,v 1.4 2004/02/17 19:47:18 gruberroland Exp $
+$Id: conflogin.php,v 1.34 2005/06/28 15:46:41 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
   Copyright (C) 2003  Roland Gruber
@@ -19,11 +19,20 @@ $Id: conflogin.php,v 1.4 2004/02/17 19:47:18 gruberroland Exp $
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-
-  Login page to change the preferences.
 */
 
+
+/**
+* Login page to change the preferences.
+*
+* @package configuration
+* @author Roland Gruber
+*/
+
+
+/** Access to config functions */
 include_once('../../lib/config.inc');
+/** Used to print status messages */
 include_once('../../lib/status.inc');
 
 // start session
@@ -41,12 +50,6 @@ unset($_SESSION['conf_admins']);
 unset($_SESSION['conf_suffusers']);
 unset($_SESSION['conf_suffgroups']);
 unset($_SESSION['conf_suffhosts']);
-unset($_SESSION['conf_minUID']);
-unset($_SESSION['conf_maxUID']);
-unset($_SESSION['conf_minGID']);
-unset($_SESSION['conf_maxGID']);
-unset($_SESSION['conf_minMach']);
-unset($_SESSION['conf_maxMach']);
 unset($_SESSION['conf_usrlstattr']);
 unset($_SESSION['conf_grplstattr']);
 unset($_SESSION['conf_hstlstattr']);
@@ -54,15 +57,8 @@ unset($_SESSION['conf_maxlistentries']);
 unset($_SESSION['conf_lang']);
 unset($_SESSION['conf_scriptpath']);
 unset($_SESSION['conf_scriptserver']);
-unset($_SESSION['conf_samba3']);
-unset($_SESSION['conf_pwdhash']);
 unset($_SESSION['conf_filename']);
 
-// remove config wizard settings
-unset($_SESSION['confwiz_config']);
-unset($_SESSION['confwiz_ldap']);
-unset($_SESSION['confwiz_masterpwd']);
-
 echo $_SESSION['header'];
 
 ?>
@@ -75,6 +71,17 @@ echo $_SESSION['header'];
 		<link rel="stylesheet" type="text/css" href="../../style/layout.css">
 	</head>
 	<body>
+		<?php
+			// set focus on password field
+			echo "<script type=\"text/javascript\" language=\"javascript\">\n";
+			echo "<!--\n";
+			echo "window.onload = function() {\n";
+				echo "loginField = document.getElementsByName('passwd')[0];\n";
+				echo "loginField.focus();\n";
+			echo "}\n";
+			echo "//-->\n";
+			echo "</script>\n";
+		?>
 		<p align="center"><a href="http://lam.sf.net" target="_blank">
 			<img src="../../graphics/banner.jpg" border=1 alt="LDAP Account Manager"></a>
 		</p>
@@ -84,54 +91,66 @@ echo $_SESSION['header'];
 		<table align="center" border="2" rules="none" bgcolor="white">
 			<tr>
 				<td style="border-style:none" rowspan="3" width="20"></td>
-				<td style="border-style:none" colspan="2" height="20"></td>
+				<td style="border-style:none" height="20"></td>
 				<td style="border-style:none" rowspan="3" width="20"></td>
 			</tr>
 			<tr>
-				<td style="border-style:none" colspan=2 align="center"><b> <?php echo _("Please enter password to change preferences:"); ?> </b></td>
+				<td style="border-style:none" align="center"><b> <?php echo _("Please enter password to change preferences:"); ?> </b></td>
 			</tr>
-			<tr><td style="border-style:none" colspan=2 >&nbsp;</td></tr>
+			<tr><td style="border-style:none" >&nbsp;</td></tr>
 <?php
-	// print message if login was incorrect
-	if ($message) {
-		echo ("<tr><td style=\"border-style:none\" rowspan=\"2\"></td>" .
-			"<td style=\"border-style:none\" colspan=2 align=\"center\"><b><font color=red>" . $message . "</font></b></td>" .
-			"<td style=\"border-style:none\" rowspan=\"2\"></td></tr>");
-		echo "<tr><td style=\"border-style:none\" colspan=2 >&nbsp;</td></tr>";
+	if (!isset($message)) $message = "";
+	$files = getConfigProfiles();
+	if (sizeof($files) < 1) $message = _("No configuration profiles found. Please create one.");
+	// print message if login was incorrect or no config profiles are present
+	if (isset($message)) {  // $message is set by confmain.php (requires conflogin.php then)
+		echo "<tr>\n";
+			echo "<td style=\"border-style:none\" rowspan=\"2\"></td>\n";
+			echo "<td style=\"border-style:none\" align=\"center\"><b><font color=red>" . $message . "</font></b></td>\n";
+			echo "<td style=\"border-style:none\" rowspan=\"2\"></td>\n";
+		echo "</tr>\n";
+		echo "<tr>\n";
+			echo "<td style=\"border-style:none\" >&nbsp;</td>\n";
+		echo "</tr>\n";
 	}
 ?>
 			<tr>
 				<td style="border-style:none" rowspan="4" width="20"></td>
-				<td style="border-style:none" colspan=2 align="center">
-					<select size=1 name="filename">
+				<td style="border-style:none" align="center">
 					<?php
-						$files = getConfigProfiles();
+						if (sizeof($files) > 0) {
+							echo "<select size=1 name=\"filename\">\n";
 							$conf = new CfgMain();
 							$defaultprofile = $conf->default;
 							for ($i = 0; $i < sizeof($files); $i++) {
 								if ($files[$i] == $defaultprofile) echo ("<option selected>" . $files[$i] . "</option>\n");
 								else echo ("<option>" . $files[$i] . "</option>\n");
 							}
+							echo "</select>\n";
+						}
+						else echo "<select disabled size=1 name=\"filename\">\n<option></option>\n</select>\n";
+						if (sizeof($files) > 0) echo "<input type=\"password\" name=\"passwd\">\n";
+						else echo "<input disabled type=\"password\" name=\"passwd\">\n";
+						if (sizeof($files) > 0) echo "<input type=\"submit\" name=\"submit\" value=\"" . _("Ok") . "\">\n";
+						else echo "<input disabled type=\"submit\" name=\"submit\" value=\"" . _("Ok") . "\">\n";
+						// help link
+						echo "&nbsp;<a href=\"../help.php?HelpNumber=200\" target=\"lamhelp\">";
+						echo "<img src=\"../../graphics/help.png\" alt=\"" . _('Help') . "\" title=\"" . _('Help') . "\">";
+						echo "</a>\n";
 					?>
-					</select>
-					<input type="password" name="passwd">
-					<input type="submit" name="submit" value=" <?php echo _("Ok"); ?> ">
-					<a href="../help.php?HelpNumber=200" target="lamhelp"><?php echo _("Help") ?></a></td>
+				</td>
 				<td style="border-style:none" rowspan="4" width="20"></td>
 			</tr>
 			<tr>
-				<td  style="border-style:none"colspan=2>&nbsp;</td>
+				<td  style="border-style:none">&nbsp;</td>
 			</tr>
 			<tr>
-				<td style="border-style:none" align="left">
+				<td style="border-style:none" align="center">
 					<b><a href="profmanage.php"><?php echo _("Manage profiles") ?></a></b>
 				</td>
-				<td style="border-style:none" align="right">
-					<b><a href="../confwiz/start.php"><?php echo _("Configuration wizard") ?></a></b>
-				</td>
 			</tr>
 			<tr>
-				<td style="border-style:none" colspan=2 height="20"></td>
+				<td style="border-style:none" height="20"></td>
 			</tr>
 		</table>
 		</form>
