@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: confsave.php,v 1.4 2004/08/14 12:38:58 gruberroland Exp $
+$Id: confsave.php,v 1.49 2005/04/14 17:42:13 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
   Copyright (C) 2003  Roland Gruber
@@ -19,10 +19,18 @@ $Id: confsave.php,v 1.4 2004/08/14 12:38:58 gruberroland Exp $
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-
-  confsave saves the new preferences to lam.conf
-
 */
+
+
+/**
+* confsave saves the new preferences to lam.conf
+*
+* @package configuration
+* @author Roland Gruber
+*/
+
+
+/** Access to config functions */
 include_once ('../../lib/config.inc');
 
 // start session
@@ -44,12 +52,7 @@ $suffusers = $_SESSION['conf_suffusers'];
 $suffgroups = $_SESSION['conf_suffgroups'];
 $suffhosts = $_SESSION['conf_suffhosts'];
 $suffdomains = $_SESSION['conf_suffdomains'];
-$minUID = $_SESSION['conf_minUID'];
-$maxUID = $_SESSION['conf_maxUID'];
-$minGID = $_SESSION['conf_minGID'];
-$maxGID = $_SESSION['conf_maxGID'];
-$minMach = $_SESSION['conf_minMach'];
-$maxMach = $_SESSION['conf_maxMach'];
+$sufftree = $_SESSION['conf_sufftree'];
 $usrlstattr = $_SESSION['conf_usrlstattr'];
 $grplstattr = $_SESSION['conf_grplstattr'];
 $hstlstattr = $_SESSION['conf_hstlstattr'];
@@ -57,14 +60,12 @@ $maxlistentries = $_SESSION['conf_maxlistentries'];
 $lang = $_SESSION['conf_lang'];
 $scriptpath = $_SESSION['conf_scriptpath'];
 $scriptserver = $_SESSION['conf_scriptserver'];
-$samba3 = $_SESSION['conf_samba3'];
-$pwdhash = $_SESSION['conf_pwdhash'];
-$pdftext = $_SESSION['conf_pdf_usertext'];
 $filename = $_SESSION['conf_filename'];
 
 // check if password is correct
 // if not: load login page
 if ($passwd != $conf->get_Passwd()) {
+	/** go back to login if password is invalid */
 	require('conflogin.php');
 	exit;
 }
@@ -87,12 +88,6 @@ if (get_magic_quotes_gpc() == 1) {
 }
 
 // check new preferences
-if (!$conf->set_samba3($samba3)) {
-	echo ("<font color=\"red\"><b>" . _("Samba version is not defined!") . "</b></font>");
-	echo ("\n<br><br><br><a href=\"javascript:history.back()\">" . _("Back to preferences...") . "</a>");
-	exit;
-}
-
 if (!$conf->set_ServerURL($serverurl)) {
 	echo ("<font color=\"red\"><b>" . _("Server Address is empty!") . "</b></font>");
 	echo ("\n<br><br><br><a href=\"javascript:history.back()\">" . _("Back to preferences...") . "</a>");
@@ -108,67 +103,42 @@ if (!$conf->set_Adminstring($admins)) {
 	echo ("\n<br><br><br><a href=\"javascript:history.back()\">" . _("Back to preferences...") . "</a>");
 	exit;
 }
-if (!$conf->set_UserSuffix($suffusers)) {
+if (!$conf->set_Suffix('user', $suffusers)) {
 	echo ("<font color=\"red\"><b>" . _("UserSuffix is invalid!") . "</b></font>");
 	echo ("\n<br><br><br><a href=\"javascript:history.back()\">" . _("Back to preferences...") . "</a>");
 	exit;
 }
-if (!$conf->set_GroupSuffix($suffgroups)) {
+if (!$conf->set_Suffix('group', $suffgroups)) {
 	echo ("<font color=\"red\"><b>" . _("GroupSuffix is invalid!") . "</b></font>");
 	echo ("\n<br><br><br><a href=\"javascript:history.back()\">" . _("Back to preferences...") . "</a>");
 	exit;
 }
-if (!$conf->set_HostSuffix($suffhosts)) {
+if (!$conf->set_Suffix('host', $suffhosts)) {
 	echo ("<font color=\"red\"><b>" . _("HostSuffix is invalid!") . "</b></font>");
 	echo ("\n<br><br><br><a href=\"javascript:history.back()\">" . _("Back to preferences...") . "</a>");
 	exit;
 }
-if (!$conf->set_DomainSuffix($suffdomains)) {
+if (!$conf->set_Suffix('domain', $suffdomains)) {
 	echo ("<font color=\"red\"><b>" . _("DomainSuffix is invalid!") . "</b></font>");
 	echo ("\n<br><br><br><a href=\"javascript:history.back()\">" . _("Back to preferences...") . "</a>");
 	exit;
 }
-if (!$conf->set_minUID($minUID)) {
-	echo ("<font color=\"red\"><b>" . _("Minimum UID number is invalid!") . "</b></font>");
+if (!$conf->set_Suffix("tree", $sufftree)) {
+	echo ("<font color=\"red\"><b>" . _("TreeSuffix is invalid!") . "</b></font>");
 	echo ("\n<br><br><br><a href=\"javascript:history.back()\">" . _("Back to preferences...") . "</a>");
 	exit;
 }
-if (!$conf->set_maxUID($maxUID)) {
-	echo ("<font color=\"red\"><b>" . _("Maximum UID number is invalid!") . "</b></font>");
-	echo ("\n<br><br><br><a href=\"javascript:history.back()\">" . _("Back to preferences...") . "</a>");
-	exit;
-}
-if (!$conf->set_minGID($minGID)) {
-	echo ("<font color=\"red\"><b>" . _("Minimum GID number is invalid!") . "</b></font>");
-	echo ("\n<br><br><br><a href=\"javascript:history.back()\">" . _("Back to preferences...") . "</a>");
-	exit;
-}
-if (!$conf->set_maxGID($maxGID)) {
-	echo ("<font color=\"red\"><b>" . _("Maximum GID number is invalid!") . "</b></font>");
-	echo ("\n<br><br><br><a href=\"javascript:history.back()\">" . _("Back to preferences...") . "</a>");
-	exit;
-}
-if (!$conf->set_minMachine($minMach)) {
-	echo ("<font color=\"red\"><b>" . _("Minimum Machine number is invalid!") . "</b></font>");
-	echo ("\n<br><br><br><a href=\"javascript:history.back()\">" . _("Back to preferences...") . "</a>");
-	exit;
-}
-if (!$conf->set_maxMachine($maxMach)) {
-	echo ("<font color=\"red\"><b>" . _("Maximum Machine number is invalid!") . "</b></font>");
-	echo ("\n<br><br><br><a href=\"javascript:history.back()\">" . _("Back to preferences...") . "</a>");
-	exit;
-}
-if (!$conf->set_userlistAttributes($usrlstattr)) {
+if (!$conf->set_listAttributes($usrlstattr, 'user')) {
 	echo ("<font color=\"red\"><b>" . _("User list attributes are invalid!") . "</b></font>");
 	echo ("\n<br><br><br><a href=\"javascript:history.back()\">" . _("Back to preferences...") . "</a>");
 	exit;
 }
-if (!$conf->set_grouplistAttributes($grplstattr)) {
+if (!$conf->set_listAttributes($grplstattr, 'group')) {
 	echo ("<font color=\"red\"><b>" . _("Group list attributes are invalid!") . "</b></font>");
 	echo ("\n<br><br><br><a href=\"javascript:history.back()\">" . _("Back to preferences...") . "</a>");
 	exit;
 }
-if (!$conf->set_hostlistAttributes($hstlstattr)) {
+if (!$conf->set_listAttributes($hstlstattr, 'host')) {
 	echo ("<font color=\"red\"><b>" . _("Host list attributes are invalid!") . "</b></font>");
 	echo ("\n<br><br><br><a href=\"javascript:history.back()\">" . _("Back to preferences...") . "</a>");
 	exit;
@@ -186,7 +156,7 @@ if (!$conf->set_defaultLanguage($lang)) {
 }
 
 if (!$conf->set_scriptpath($scriptpath)) {
-	echo ("<font color=\"red\"><b>" . _("Logon script is invalid!") . "</b></font>");
+	echo ("<font color=\"red\"><b>" . _("Script path is invalid!") . "</b></font>");
 	echo ("\n<br><br><br><a href=\"javascript:history.back()\">" . _("Back to preferences...") . "</a>");
 	exit;
 }
@@ -197,18 +167,72 @@ if (!$conf->set_scriptserver($scriptserver)) {
 	exit;
 }
 
-if (!$conf->set_pwdhash($pwdhash)) {
-	echo ("<font color=\"red\"><b>" . _("Password hash is invalid!") . "</b></font>");
+if (! $conf->set_AccountModules($_SESSION['conf_usermodules'], 'user')) {
+	echo ("<font color=\"red\"><b>" . _("Saving user modules failed!") . "</b></font>");
 	echo ("\n<br><br><br><a href=\"javascript:history.back()\">" . _("Back to preferences...") . "</a>");
 	exit;
 }
 
-if (!$conf->set_pdftext($pdftext)) {
-	echo ("<font color=\"red\"><b>" . _("Saving PDF text failed!") . "</b></font>");
+if (! $conf->set_AccountModules($_SESSION['conf_groupmodules'], 'group')) {
+	echo ("<font color=\"red\"><b>" . _("Saving group modules failed!") . "</b></font>");
 	echo ("\n<br><br><br><a href=\"javascript:history.back()\">" . _("Back to preferences...") . "</a>");
 	exit;
 }
 
+if (! $conf->set_AccountModules($_SESSION['conf_hostmodules'], 'host')) {
+	echo ("<font color=\"red\"><b>" . _("Saving host modules failed!") . "</b></font>");
+	echo ("\n<br><br><br><a href=\"javascript:history.back()\">" . _("Back to preferences...") . "</a>");
+	exit;
+}
+
+// check module options
+// create option array to check and save
+$options = array();
+$opt_keys = array_keys($_SESSION['config_types']);
+foreach ($opt_keys as $element) {
+	// text fields
+	if ($_SESSION['config_types'][$element] == "text") {
+		$options[$element] = array($_SESSION['config_moduleSettings'][$element]);
+	}
+	// checkboxes
+	elseif ($_SESSION['config_types'][$element] == "checkbox") {
+		if ($_SESSION['config_moduleSettings'][$element] == "on") $options[$element] = array('true');
+		else $options[$element] = array('false');
+	}
+	// dropdownbox
+	elseif ($_SESSION['config_types'][$element] == "select") {
+		$options[$element] = array($_SESSION['config_moduleSettings'][$element]);
+	}
+	// multiselect
+	elseif ($_SESSION['config_types'][$element] == "multiselect") {
+		$options[$element] = $_SESSION['config_moduleSettings'][$element];  // value is already an array
+	}
+}
+
+// remove double slashes if magic quotes are on
+if (get_magic_quotes_gpc() == 1) {
+	foreach ($opt_keys as $element) {
+		if (is_string($options[$element][0])) $options[$element][0] = stripslashes($options[$element][0]);
+	}
+}
+
+// check options
+$errors = checkConfigOptions($_SESSION['config_scopes'], $options);
+// print error messages if any
+if (sizeof($errors) > 0) {
+	for ($i = 0; $i < sizeof($errors); $i++) {
+		if (sizeof($errors[$i]) > 3) {  // messages with additional variables
+			StatusMessage($errors[$i][0], $errors[$i][1], $errors[$i][2], $errors[$i][3]);
+		}
+		else {
+			StatusMessage($errors[$i][0], $errors[$i][1], $errors[$i][2]);
+		}
+	}
+	echo ("\n<br><br><br><a href=\"javascript:history.back()\">" . _("Back to preferences...") . "</a>");
+	exit;
+}
+// save module setting
+$conf->set_moduleSettings($options);
 
 // check if password was changed
 if ($passwd1) {
@@ -242,12 +266,7 @@ unset($_SESSION['conf_suffusers']);
 unset($_SESSION['conf_suffgroups']);
 unset($_SESSION['conf_suffhosts']);
 unset($_SESSION['conf_suffdomains']);
-unset($_SESSION['conf_minUID']);
-unset($_SESSION['conf_maxUID']);
-unset($_SESSION['conf_minGID']);
-unset($_SESSION['conf_maxGID']);
-unset($_SESSION['conf_minMach']);
-unset($_SESSION['conf_maxMach']);
+unset($_SESSION['conf_sufftree']);
 unset($_SESSION['conf_usrlstattr']);
 unset($_SESSION['conf_grplstattr']);
 unset($_SESSION['conf_hstlstattr']);
@@ -255,9 +274,9 @@ unset($_SESSION['conf_maxlistentries']);
 unset($_SESSION['conf_lang']);
 unset($_SESSION['conf_scriptpath']);
 unset($_SESSION['conf_scriptserver']);
-unset($_SESSION['conf_samba3']);
-unset($_SESSION['conf_pwdhash']);
-unset($_SESSION['conf_pdf_usertext']);
 unset($_SESSION['conf_filename']);
+unset($_SESSION['conf_usermodules']);
+unset($_SESSION['conf_groupmodules']);
+unset($_SESSION['conf_hostmodules']);
 
 ?>
