@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: profmanage.php,v 1.1.1.1 2003/12/29 22:11:29 gruberroland Exp $
+$Id: profmanage.php,v 1.16 2005/04/24 19:41:39 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
   Copyright (C) 2003  Roland Gruber
@@ -19,11 +19,20 @@ $Id: profmanage.php,v 1.1.1.1 2003/12/29 22:11:29 gruberroland Exp $
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-
-  Configuration profile management.
 */
 
+  
+/**
+* Configuration profile management.
+*
+* @package configuration
+* @author Roland Gruber
+*/
+
+
+/** Access to config functions */
 include_once('../../lib/config.inc');
+/** Used to print status messages */
 include_once('../../lib/status.inc');
 
 // start session
@@ -51,9 +60,9 @@ echo $_SESSION['header'];
 
 <?php
 
+$cfg = new CfgMain();
 // check if submit button was pressed
 if ($_POST['submit']) {
-	$cfg = new CfgMain();
 	// check master password
 	if ($cfg->password != $_POST['passwd']) {
 		$error = _("Master password is wrong!");
@@ -133,6 +142,14 @@ if ($_POST['submit']) {
 	else exit;
 }
 
+
+// check if config.cfg is valid
+if (!isset($cfg->default) && !isset($cfg->password)) {
+	StatusMessage("ERROR", _("Please set up your master configuration file (config/config.cfg) first!"), "");
+	echo "</body>\n</html>\n";
+	die();
+}
+
 ?>
 
 		<br>
@@ -160,7 +177,12 @@ if ($_POST['submit']) {
 						<input type="text" name="addprofile">
 					</td>
 					<td>&nbsp;
-						<a href="../help.php?HelpNumber=230" target="lamhelp"><?php echo _("Help"); ?></a>
+					<?PHP
+						// help link
+						echo "<a href=\"../help.php?HelpNumber=230\" target=\"lamhelp\">";
+						echo "<img src=\"../../graphics/help.png\" alt=\"" . _('Help') . "\" title=\"" . _('Help') . "\">";
+						echo "</a>\n";
+					?>
 					</td>
 				</tr>
 				<tr bgcolor="#dbdbff">
@@ -207,7 +229,12 @@ if ($_POST['submit']) {
 						<input type="text" name="renfilename">
 					</td>
 					<td>&nbsp;
-						<a href="../help.php?HelpNumber=231" target="lamhelp"><?php echo _("Help"); ?></a>
+					<?PHP
+						// help link
+						echo "<a href=\"../help.php?HelpNumber=231\" target=\"lamhelp\">";
+						echo "<img src=\"../../graphics/help.png\" alt=\"" . _('Help') . "\" title=\"" . _('Help') . "\">";
+						echo "</a>\n";
+					?>
 					</td>
 				</tr>
 
@@ -232,7 +259,12 @@ if ($_POST['submit']) {
 						</b>
 					</td>
 					<td>&nbsp;
-						<a href="../help.php?HelpNumber=232" target="lamhelp"><?php echo _("Help"); ?></a>
+					<?PHP
+						// help link
+						echo "<a href=\"../help.php?HelpNumber=232\" target=\"lamhelp\">";
+						echo "<img src=\"../../graphics/help.png\" alt=\"" . _('Help') . "\" title=\"" . _('Help') . "\">";
+						echo "</a>\n";
+					?>
 					</td>
 				</tr>
 
@@ -261,7 +293,12 @@ if ($_POST['submit']) {
 						<input type="password" name="setpassword">
 					</td>
 					<td>&nbsp;
-						<a href="../help.php?HelpNumber=233" target="lamhelp"><?php echo _("Help"); ?></a>
+					<?PHP
+						// help link
+						echo "<a href=\"../help.php?HelpNumber=233\" target=\"lamhelp\">";
+						echo "<img src=\"../../graphics/help.png\" alt=\"" . _('Help') . "\" title=\"" . _('Help') . "\">";
+						echo "</a>\n";
+					?>
 					</td>
 				</tr>
 				<tr bgcolor="#dbdbff">
@@ -304,7 +341,12 @@ if ($_POST['submit']) {
 					</td>
 					<td>&nbsp;</td>
 					<td>&nbsp;
-						<a href="../help.php?HelpNumber=234" target="lamhelp"><?php echo _("Help"); ?></a>
+					<?PHP
+						// help link
+						echo "<a href=\"../help.php?HelpNumber=234\" target=\"lamhelp\">";
+						echo "<img src=\"../../graphics/help.png\" alt=\"" . _('Help') . "\" title=\"" . _('Help') . "\">";
+						echo "</a>\n";
+					?>
 					</td>
 				</tr>
 
@@ -327,7 +369,12 @@ if ($_POST['submit']) {
 						<input type="password" name="masterpassword">
 					</td>
 					<td>&nbsp;
-						<a href="../help.php?HelpNumber=235" target="lamhelp"><?php echo _("Help"); ?></a>
+					<?PHP
+						// help link
+						echo "<a href=\"../help.php?HelpNumber=235\" target=\"lamhelp\">";
+						echo "<img src=\"../../graphics/help.png\" alt=\"" . _('Help') . "\" title=\"" . _('Help') . "\">";
+						echo "</a>\n";
+					?>
 					</td>
 				</tr>
 				<tr bgcolor="#dbdbff">
@@ -355,7 +402,12 @@ if ($_POST['submit']) {
 			&nbsp
 			<input type="submit" name="submit" value=" <?php echo _("Submit"); ?> ">
 			&nbsp
-			<a href="../help.php?HelpNumber=236" target="lamhelp"><?php echo _("Help"); ?></a>
+			<?PHP
+				// help link
+				echo "<a href=\"../help.php?HelpNumber=236\" target=\"lamhelp\">";
+				echo "<img src=\"../../graphics/help.png\" alt=\"" . _('Help') . "\" title=\"" . _('Help') . "\">";
+				echo "</a>\n";
+			?>
 
 		</form>
 		<p><br></p>
