@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: initsuff.php,v 1.3 2004/02/16 16:40:00 gruberroland Exp $
+$Id: initsuff.php,v 1.13 2005/01/22 11:05:44 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
   Copyright (C) 2003  Roland Gruber
@@ -19,12 +19,20 @@ $Id: initsuff.php,v 1.3 2004/02/16 16:40:00 gruberroland Exp $
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-  Creates main suffixes if they are missing.
-
 */
 
+/**
+* Creates main suffixes if they are missing.
+*
+* @author Roland Gruber
+* @package main
+*/
+
+/** access to configuration settings */
 include_once ("../lib/config.inc");
+/** LDAP access */
 include_once ("../lib/ldap.inc");
+/** status messages */
 include_once ("../lib/status.inc");
 
 // start session
@@ -140,36 +148,17 @@ if ($_POST['add_suff'] || $_POST['cancel']) {
 			for ($i = 0; $i < sizeof($fail); $i++) {
 				StatusMessage("ERROR", _("Failed to create entry!") . "<br>" . $error[$i], $fail[$i]);
 			}
-			echo "<p>&nbsp;</p>\n";
-			echo "<a href=\"lists/listusers.php\">" . _("User list") . "</a>\n";
 			echo "</body></html>\n";
 		}
 		else {
 			// print success message
 			StatusMessage("INFO", "", _("All changes were successful."));
-			if ($_SESSION['config']->is_samba3()) {
-				$doms = $_SESSION['ldap']->search_domains($_SESSION['config']->get_domainSuffix());
-				echo "<p>&nbsp;</p>\n";
-				if (sizeof($doms) == 0) {
-					echo "<a href=\"domain.php?action=new\">" . _("No domains found, please create one.") . "</a>\n";
-				}
-				else {
-					echo "<a href=\"lists/listusers.php\">" . _("User list") . "</a>\n";
-				}
-				echo "</body></html>\n";
-			}
-			else {
-				echo "<p>&nbsp;</p>\n";
-				echo "<a href=\"lists/listusers.php\">" . _("User list") . "</a>\n";
-				echo "</body></html>\n";
-			}
+			echo "</body></html>\n";
 		}
 	}
 	else {
 		// no suffixes were created
 		StatusMessage("INFO", "", _("No changes were made."));
-		echo "<p>&nbsp;</p>\n";
-		echo "<a href=\"lists/listusers.php\">" . _("User list") . "</a>\n";
 		echo "</body></html>\n";
 	}
 	exit;
