@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: login.php,v 1.11 2005/01/15 12:11:03 duergner Exp $
+$Id: login.php,v 1.76 2005/09/30 13:53:45 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
   Copyright (C) 2003  Michael Duergner
@@ -19,21 +19,31 @@ $Id: login.php,v 1.11 2005/01/15 12:11:03 duergner Exp $
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-
-  LDAP Account Manager checking login datas.
 */
 
+/**
+* Login form of LDAP Account Manager.
+*
+* @author Michael Duergner
+* @package main
+*/
+
+/** access to configuration options */
 include_once("../lib/config.inc"); // Include config.inc which provides Config class
 
 session_save_path("../sess"); // Set session save path
-@session_start(); // Start LDAP Account Manager session
+session_start(); // Start LDAP Account Manager session
 
-function display_LoginPage($config_object,$profile)
-{
+/**
+* Displays the login window.
+*
+* @param object $config_object current active configuration
+*/
+function display_LoginPage($config_object) {
 	global $error_message;
 	// generate 256 bit key and initialization vector for user/passwd-encryption
 	// check if we can use /dev/random otherwise use /dev/urandom or rand()
-	if(function_exists(mcrypt_create_iv)) {
+	if(function_exists('mcrypt_create_iv')) {
 		$key = @mcrypt_create_iv(32, MCRYPT_DEV_RANDOM);
 		if (! $key) $key = @mcrypt_create_iv(32, MCRYPT_DEV_URANDOM);
 		if (! $key) {
@@ -46,19 +56,10 @@ function display_LoginPage($config_object,$profile)
 			srand((double)microtime()*1234567);
 			$iv = mcrypt_create_iv(32, MCRYPT_RAND);
 		}
+		// save both in cookie
+		setcookie("Key", base64_encode($key), 0, "/");
+		setcookie("IV", base64_encode($iv), 0, "/");
 	}
-	// use Blowfish if MCrypt is not available
-	else {
-		// generate iv and key for encryption
-		$key = "";
-		$iv = "";
-		while (strlen($key) < 30) $key .= mt_rand();
-		while (strlen($iv) < 30) $iv .= mt_rand();
-	}
-
-	// save both in cookie
-	setcookie("Key", base64_encode($key), 0, "/");
-	setcookie("IV", base64_encode($iv), 0, "/");
 
 	$_SESSION['language'] = $config_object->get_defaultLanguage();
 
@@ -94,11 +95,6 @@ function display_LoginPage($config_object,$profile)
 		}
 		fclose($file);
 	}
-	else
-	{
-		//TODO Generate Status message
-		$message = _("Unable to load available languages. Setting English as default language. For further instructions please contact the Admin of this site.");
-	}
 
 	$profiles = getConfigProfiles();
 
@@ -110,18 +106,34 @@ function display_LoginPage($config_object,$profile)
 		<link rel="stylesheet" type="text/css" href="../style/layout.css">
 	</head>
 	<body>
+	<?php
+		// set focus on password field
+		echo "<script type=\"text/javascript\" language=\"javascript\">\n";
+		echo "<!--\n";
+		echo "window.onload = function() {\n";
+			echo "loginField = document.getElementsByName('passwd')[0];\n";
+			echo "loginField.focus();\n";
+		echo "}\n";
+		echo "//-->\n";
+		echo "</script>\n";
+	?>
 		<p align="center">
 			<a href="http://lam.sf.net" target="_blank"><img src="../graphics/banner.jpg" border="1" alt="LDAP Account Manager"></a>
 		</p>
 		<table width="100%" border="0">
 			<tr>
 				<td width="100%" align="right">
-					<a href="./config/conflogin.php" target="_self"><?php echo _("Configuration Login"); ?></a>
+					<a href="./config/conflogin.php" target="_self"><?php echo _("Configuration login"); ?></a>
 				</td>
 			</tr>
 		</table>
 		<hr><br><br>
 		<?php
+		// check if PHP has session support
+		if (! function_exists('session_start')) {
+			StatusMessage("ERROR", "Your PHP has no session support!", "Please install the session extension for PHP.");
+			echo "<br><br>";
+		}
 		// check if all password hashes are possible
 		if ((! function_exists('mHash')) && (! function_exists('sha1'))) {
 			StatusMessage("INFO", "Your PHP does not support MHash or sha1(), you will only be able to use CRYPT/PLAIN/MD5/SMD5 for user passwords!", "Please install MHash or update to PHP >4.3.");
@@ -132,6 +144,11 @@ function display_LoginPage($config_object,$profile)
 			StatusMessage("ERROR", "Your PHP has no LDAP support!", "Please install the LDAP extension for PHP.");
 			echo "<br><br>";
 		}
+		// check if PHP has gettext support
+		if (! function_exists('gettext')) {
+			StatusMessage("ERROR", "Your PHP has no gettext support!", "Please install gettext for PHP.");
+			echo "<br><br>";
+		}
 		?>
 		<table width="650" align="center" border="2" rules="none" bgcolor="white">
 			<tr>
@@ -143,16 +160,13 @@ function display_LoginPage($config_object,$profile)
 						<table width="580">
 							<tr>
 								<td style="border-style:none" height="70" colspan="2" align="center">
-									<font color="darkblue"><b><big><?php echo _("Enter Username and Password for Account"); ?></big></b></font>
-								</td>
-								<td style="border-style:none" rowspan="9" width="70">
-									&nbsp;
+									<font color="darkblue"><b><big><?php echo _("Please select your user name and enter your password to log in"); ?></big></b></font>
 								</td>
 							</tr>
 							<tr>
 								<td style="border-style:none" height="35" align="right"><b>
 									<?php
-									echo _("Username") . ":";
+									echo _("User name") . ":";
 									?>
 								</b>&nbsp;&nbsp;</td>
 								<td style="border-style:none" height="35" align="left">
@@ -181,22 +195,9 @@ function display_LoginPage($config_object,$profile)
 								</td>
 							</tr>
 							<tr>
-							<?php
-							if($message != "") {
-								?>
-								<td height="35" colspan="3" align="center">
-								<?php
-									echo $message;
-								?>
-								</td>
-								<?php
-							}
-							else
-							{
-								?>
 								<td style="border-style:none" align="right"><b>
 									<?php
-									echo _("Your Language") . ":";
+									echo _("Language") . ":";
 									?>
 								</b>&nbsp;&nbsp;</td>
 								<td style="border-style:none" height="35" align="left">
@@ -218,9 +219,6 @@ function display_LoginPage($config_object,$profile)
 									?>
 									</select>
 								</td>
-								<?php
-							}
-							?>
 							</tr>
 							<tr>
 								<td style="border-style:none" height="50" colspan="2" align="center">
@@ -229,7 +227,7 @@ function display_LoginPage($config_object,$profile)
 								</td>
 							</tr>
 							<tr>
-								<td style="border-style:none" height="50" colspan="2" align="center">
+								<td style="border-style:none" colspan="2" align="center">
 									<?php
 										if($error_message != "") {
 											echo "<font color=\"red\"><b>" . $error_message . "</b></font>";
@@ -276,7 +274,7 @@ function display_LoginPage($config_object,$profile)
 								?>
 								</select>
 								<input name="profileChange" type="hidden" value="profileChange">
-								<input name="submit" type="submit" value="<?php echo _("Change Profile"); ?>" tabindex="5">
+								<input name="submit" type="submit" value="<?php echo _("Change profile"); ?>" tabindex="5">
 							</td>
 							</tr>
 							<tr>
@@ -288,6 +286,15 @@ function display_LoginPage($config_object,$profile)
 			</tr>
 		</table>
 		<br><br>
+			<TABLE style="position:absolute; bottom:10px;" border="0" width="99%">
+				<TR><TD align="right"><HR>
+					<SMALL>
+					<?php
+						echo "LDAP Account Manager: <b>" . LAMVersion() . "</b>&nbsp;&nbsp;&nbsp;";
+					?>
+					</SMALL>
+				</TD></TR>
+			</TABLE>
 	</body>
 </html>
 <?php
@@ -304,8 +311,8 @@ if($_POST['checklogin'])
 
 	if($_POST['passwd'] == "")
 	{
-		$error_message = _("Empty Password submitted. Try again.");
-		display_LoginPage($_SESSION['config'],""); // Empty password submitted. Return to login page.
+		$error_message = _("Empty password submitted. Please try again.");
+		display_LoginPage($_SESSION['config']); // Empty password submitted. Return to login page.
 	}
 	else
 	{
@@ -331,23 +338,23 @@ if($_POST['checklogin'])
 		{
 			if ($result === False)
 			{
-				$error_message = _("Cannot connect to specified LDAP-Server. Please try again.");
-				display_LoginPage($_SESSION['config'],""); // connection failed
+				$error_message = _("Cannot connect to specified LDAP server. Please try again.");
+				display_LoginPage($_SESSION['config']); // connection failed
 			}
 			elseif ($result == 81)
 			{
-				$error_message = _("Cannot connect to specified LDAP-Server. Please try again.");
-				display_LoginPage($_SESSION['config'],""); // connection failed
+				$error_message = _("Cannot connect to specified LDAP server. Please try again.");
+				display_LoginPage($_SESSION['config']); // connection failed
 			}
 			elseif ($result == 49)
 			{
-				$error_message = _("Wrong Password/Username combination. Try again.");
-				display_LoginPage($_SESSION['config'],""); // Username/password invalid. Return to login page.
+				$error_message = _("Wrong password/user name combination. Please try again.");
+				display_LoginPage($_SESSION['config']); // Username/password invalid. Return to login page.
 			}
 			else
 			{
 				$error_message = _("LDAP error, server says:") .  "\n<br>($result) " . ldap_err2str($result);
-				display_LoginPage($_SESSION['config'],""); // other errors
+				display_LoginPage($_SESSION['config']); // other errors
 			}
 		}
 	}
@@ -355,8 +362,7 @@ if($_POST['checklogin'])
 // Reload loginpage after a profile change
 elseif($_POST['profileChange']) {
 	$_SESSION['config'] = new Config($_POST['profile']); // Recreate the config object with the submited
-
-	display_LoginPage($_SESSION['config'],""); // Load login page
+	display_LoginPage($_SESSION['config']); // Load login page
 }
 // Load login page
 else
@@ -366,6 +372,6 @@ else
 	$default_Profile = $default_Config->default;
 	$_SESSION["config"] = new Config($default_Profile); // Create new Config object
 
-	display_LoginPage($_SESSION["config"],$default_Profile); // Load Login page
+	display_LoginPage($_SESSION["config"]); // Load Login page
 }
 ?>
