@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: main.php,v 1.2 2004/07/04 11:06:46 gruberroland Exp $
+$Id: main.php,v 1.27 2005/03/10 20:19:57 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
   Copyright (C) 2003  Roland Gruber
@@ -19,36 +19,54 @@ $Id: main.php,v 1.2 2004/07/04 11:06:46 gruberroland Exp $
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-  This is the main window. The user and group lists will be shown in this frame.
-
 */
 
+/**
+* This is the main window. The user and group lists will be shown in this frameset.
+*
+* @package main
+* @author Roland Gruber
+*/
+
+/** LDAP attibute cache */
+include_once('../lib/cache.inc');
+
+// create cache object
+if (!isset($_SESSION['cache'])) {
+	$_SESSION['cache'] = new cache();
+}
+
+$startPage = "";
+
 // check if all suffixes in conf-file exist
 $conf = $_SESSION['config'];
 $new_suffs = array();
-if ($conf->get_UserSuffix() && ($conf->get_UserSuffix() != "")) {
-	$info = @ldap_search($_SESSION['ldap']->server, $conf->get_UserSuffix(), "", array());
+if ($conf->get_Suffix('user') && ($conf->get_Suffix('user') != "")) {
+	$startPage = "./lists/listusers.php";
+	$info = @ldap_search($_SESSION['ldap']->server, $conf->get_Suffix('user'), "", array());
 	$res = @ldap_get_entries($_SESSION['ldap']->server, $info);
-	if (!$res && !in_array($conf->get_UserSuffix(), $new_suffs)) $new_suffs[] = $conf->get_UserSuffix();
+	if (!$res && !in_array($conf->get_Suffix('user'), $new_suffs)) $new_suffs[] = $conf->get_Suffix('user');
 }
-if ($conf->get_GroupSuffix() && ($conf->get_GroupSuffix() != "")) {
-	$info = @ldap_search($_SESSION['ldap']->server, $conf->get_GroupSuffix(), "", array());
+if ($conf->get_Suffix('group') && ($conf->get_Suffix('group') != "")) {
+	if ($startPage == "") {
+		$startPage = "./lists/listgroups.php";
+	}
+	$info = @ldap_search($_SESSION['ldap']->server, $conf->get_Suffix('group'), "", array());
 	$res = @ldap_get_entries($_SESSION['ldap']->server, $info);
-	if (!$res && !in_array($conf->get_GroupSuffix(), $new_suffs)) $new_suffs[] = $conf->get_GroupSuffix();
+	if (!$res && !in_array($conf->get_Suffix('group'), $new_suffs)) $new_suffs[] = $conf->get_Suffix('group');
 }
-if ($conf->get_HostSuffix() && ($conf->get_HostSuffix() != "")) {
-	$info = @ldap_search($_SESSION['ldap']->server, $conf->get_HostSuffix(), "", array());
+if ($conf->get_Suffix('host') && ($conf->get_Suffix('host') != "")) {
+	if ($startPage == "") {
+		$startPage = "./lists/listhosts.php";
+	}
+	$info = @ldap_search($_SESSION['ldap']->server, $conf->get_Suffix('host'), "", array());
 	$res = @ldap_get_entries($_SESSION['ldap']->server, $info);
-	if (!$res && !in_array($conf->get_HostSuffix(), $new_suffs)) $new_suffs[] = $conf->get_HostSuffix();
+	if (!$res && !in_array($conf->get_Suffix('host'), $new_suffs)) $new_suffs[] = $conf->get_Suffix('host');
 }
-if ($conf->get_DomainSuffix() && ($conf->get_DomainSuffix() != "")) {
-	$info = @ldap_search($_SESSION['ldap']->server, $conf->get_DomainSuffix(), "", array());
+if ($conf->get_Suffix('domain') && ($conf->get_Suffix('domain') != "")) {
+	$info = @ldap_search($_SESSION['ldap']->server, $conf->get_Suffix('domain'), "", array());
 	$res = @ldap_get_entries($_SESSION['ldap']->server, $info);
-	if (!$res && !in_array($conf->get_DomainSuffix(), $new_suffs)) $new_suffs[] = $conf->get_DomainSuffix();
-}
-
-if ($_SESSION['config']->is_samba3()) {
-	$doms = $_SESSION['ldap']->search_domains($_SESSION['config']->get_domainSuffix());
+	if (!$res && !in_array($conf->get_Suffix('domain'), $new_suffs)) $new_suffs[] = $conf->get_Suffix('domain');
 }
 
 // get encoding
@@ -67,14 +85,10 @@ echo ("<link rel=\"stylesheet\" type=\"text/css\" href=\"../style/layout.css\">"
 echo ("</head>\n");
 echo ("<frameset rows=\"130,*\">\n");
 echo ("<frame src=\"./main_header.php\" name=\"head\" frameborder=\"0\" scrolling=\"no\" noresize>\n");
-// display page to add suffixes or add domain, if needed
+// display page to add suffixes, if needed
 if (sizeof($new_suffs) > 0) echo ("<frame src=\"initsuff.php?suffs='" . implode(";", $new_suffs) .
 	"'\" name=\"mainpart\" frameborder=\"0\" scrolling=\"yes\">\n");
-elseif (($_SESSION['config']->is_samba3()) && (sizeof($doms) < 1)) {
-	$_SESSION['domain_message'] = _("No domains found, please create one.");
-	echo ("<frame src=\"domain.php?action=new\" name=\"mainpart\" frameborder=\"0\" scrolling=\"yes\">\n");
-}
-else echo ("<frame src=\"./lists/listusers.php\" name=\"mainpart\" frameborder=\"0\" scrolling=\"yes\">\n");
+else echo ("<frame src=\"$startPage\" name=\"mainpart\" frameborder=\"0\" scrolling=\"yes\">\n");
 echo ("<noframes>\n");
 echo ("This page requires a browser that can show frames!\n");
 echo ("</noframes>\n");
