@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: ou_edit.php,v 1.1.1.1 2003/12/29 22:11:20 gruberroland Exp $
+$Id: ou_edit.php,v 1.15 2005/07/20 18:07:10 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
   Copyright (C) 2003  Roland Gruber
@@ -19,12 +19,20 @@ $Id: ou_edit.php,v 1.1.1.1 2003/12/29 22:11:20 gruberroland Exp $
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-  This is an editor for orgnizational units.
-
 */
 
+/**
+* This is an editor for organizational units.
+*
+* @author Roland Gruber
+* @package tools
+*/
+
+/** access to configuration data */
 include_once ("../lib/config.inc");
+/** access LDAP server */
 include_once ("../lib/ldap.inc");
+/** used to print status messages */
 include_once ("../lib/status.inc");
 
 // start session
@@ -320,12 +328,6 @@ exit;
 else display_main();
 
 function display_main() {
-	// generate lists of possible suffixes
-	$usr_units = $_SESSION['ldap']->search_units($_SESSION["config"]->get_UserSuffix());
-	$grp_units = $_SESSION['ldap']->search_units($_SESSION["config"]->get_GroupSuffix());
-	$hst_units = $_SESSION['ldap']->search_units($_SESSION["config"]->get_HostSuffix());
-	$dom_units = $_SESSION['ldap']->search_units($_SESSION["config"]->get_DomainSuffix());
-
 	// display main page
 	echo $_SESSION['header'];
 	echo ("<title>OU-Editor</title>\n");
@@ -336,106 +338,120 @@ function display_main() {
 	echo ("<form action=\"ou_edit.php?type=user\" method=\"post\">\n");
 
 	// user OUs
-	echo ("<fieldset><legend><b>" . _("Users") . "</b></legend>\n");
-	echo ("<table border=0>\n");
-	// new OU
-	echo ("<tr>\n");
-	echo ("<td><input type=radio name=\"type\" value=\"new_usr\" checked></td>\n");
-	echo ("<td><b>" . _("New organizational unit") . ":</b></td>\n");
-	echo ("<td>&nbsp;</td>\n");
-	echo ("<td><select size=1 name=usersuff_n>");
-	for ($i = 0; $i < sizeof($usr_units); $i++) {
-		echo ("<option>" . $usr_units[$i] . "</option>\n");
+	if ($_SESSION["config"]->get_Suffix('user') != "") {
+		// generate lists of possible suffixes
+		$usr_units = $_SESSION['ldap']->search_units($_SESSION["config"]->get_Suffix('user'));
+		echo ("<fieldset><legend><b>" . _("Users") . "</b></legend>\n");
+		echo ("<table border=0>\n");
+		// new OU
+		echo ("<tr>\n");
+		echo ("<td><input type=radio name=\"type\" value=\"new_usr\" checked></td>\n");
+		echo ("<td><b>" . _("New organizational unit") . ":</b></td>\n");
+		echo ("<td>&nbsp;</td>\n");
+		echo ("<td><select size=1 name=usersuff_n>");
+		for ($i = 0; $i < sizeof($usr_units); $i++) {
+			echo ("<option>" . $usr_units[$i] . "</option>\n");
+		}
+		echo ("</select><td>\n");
+		echo ("<td><input type=text name=newsuff_u></td>\n");
+		echo ("<td><a href=\"help.php?HelpNumber=601\" target=\"lamhelp\">". _("Help") ."</a></td>\n");
+		echo ("</tr>\n");
+		// delete OU
+		echo ("<tr>\n");
+		echo ("<td><input type=radio name=\"type\" value=\"del_usr\"></td>\n");
+		echo ("<td><b>" . _("Delete organizational unit") . ":</b></td>\n");
+		echo ("<td>&nbsp;</td>\n");
+		echo ("<td><select size=1 name=usersuff_d>");
+		for ($i = 0; $i < sizeof($usr_units); $i++) {
+			echo ("<option>" . $usr_units[$i] . "</option>\n");
+		}
+		echo ("</select><td>\n");
+		echo ("<td>&nbsp;</td>\n");
+		echo ("<td><a href=\"help.php?HelpNumber=602\" target=\"lamhelp\">". _("Help") ."</a></td>\n");
+		echo ("</tr>\n");
+		echo ("</table>\n");
+		echo ("</fieldset>\n");
+		echo ("<br>\n");
 	}
-	echo ("</select><td>\n");
-	echo ("<td><input type=text name=newsuff_u></td>\n");
-	echo ("<td><a href=\"help.php?HelpNumber=601\" target=\"lamhelp\">". _("Help") ."</a></td>\n");
-	echo ("</tr>\n");
-	// delete OU
-	echo ("<tr>\n");
-	echo ("<td><input type=radio name=\"type\" value=\"del_usr\"></td>\n");
-	echo ("<td><b>" . _("Delete organizational unit") . ":</b></td>\n");
-	echo ("<td>&nbsp;</td>\n");
-	echo ("<td><select size=1 name=usersuff_d>");
-	for ($i = 0; $i < sizeof($usr_units); $i++) {
-		echo ("<option>" . $usr_units[$i] . "</option>\n");
-	}
-	echo ("</select><td>\n");
-	echo ("<td>&nbsp;</td>\n");
-	echo ("<td><a href=\"help.php?HelpNumber=602\" target=\"lamhelp\">". _("Help") ."</a></td>\n");
-	echo ("</tr>\n");
-	echo ("</table>\n");
-	echo ("</fieldset>\n");
-	echo ("<br>\n");
 
 	// group OUs
-	echo ("<fieldset><legend><b>" . _("Groups") . "</b></legend>\n");
-	echo ("<table border=0>\n");
-	// new OU
-	echo ("<tr>\n");
-	echo ("<td><input type=radio name=\"type\" value=\"new_grp\"></td>\n");
-	echo ("<td><b>" . _("New organizational unit") . ":</b></td>\n");
-	echo ("<td>&nbsp;</td>\n");
-	echo ("<td><select size=1 name=groupsuff_n>");
-	for ($i = 0; $i < sizeof($grp_units); $i++) {
-		echo ("<option>" . $grp_units[$i] . "</option>\n");
+	if ($_SESSION["config"]->get_Suffix('group') != "") {
+		// generate lists of possible suffixes
+		$grp_units = $_SESSION['ldap']->search_units($_SESSION["config"]->get_Suffix('group'));
+		echo ("<fieldset><legend><b>" . _("Groups") . "</b></legend>\n");
+		echo ("<table border=0>\n");
+		// new OU
+		echo ("<tr>\n");
+		echo ("<td><input type=radio name=\"type\" value=\"new_grp\"></td>\n");
+		echo ("<td><b>" . _("New organizational unit") . ":</b></td>\n");
+		echo ("<td>&nbsp;</td>\n");
+		echo ("<td><select size=1 name=groupsuff_n>");
+		for ($i = 0; $i < sizeof($grp_units); $i++) {
+			echo ("<option>" . $grp_units[$i] . "</option>\n");
+		}
+		echo ("</select><td>\n");
+		echo ("<td><input type=text name=newsuff_g></td>\n");
+		echo ("<td><a href=\"help.php?HelpNumber=601\" target=\"lamhelp\">". _("Help") ."</a></td>\n");
+		echo ("</tr>\n");
+		// delete OU
+		echo ("<tr>\n");
+		echo ("<td><input type=radio name=\"type\" value=\"del_grp\"></td>\n");
+		echo ("<td><b>" . _("Delete organizational unit") . ":</b></td>\n");
+		echo ("<td>&nbsp;</td>\n");
+		echo ("<td><select size=1 name=groupsuff_d>");
+		for ($i = 0; $i < sizeof($grp_units); $i++) {
+			echo ("<option>" . $grp_units[$i] . "</option>\n");
+		}
+		echo ("</select><td>\n");
+		echo ("<td>&nbsp;</td>\n");
+		echo ("<td><a href=\"help.php?HelpNumber=602\" target=\"lamhelp\">". _("Help") ."</a></td>\n");
+		echo ("</tr>\n");
+		echo ("</table>\n");
+		echo ("</fieldset>\n");
+		echo ("<br>\n");
 	}
-	echo ("</select><td>\n");
-	echo ("<td><input type=text name=newsuff_g></td>\n");
-	echo ("<td><a href=\"help.php?HelpNumber=601\" target=\"lamhelp\">". _("Help") ."</a></td>\n");
-	echo ("</tr>\n");
-	// delete OU
-	echo ("<tr>\n");
-	echo ("<td><input type=radio name=\"type\" value=\"del_grp\"></td>\n");
-	echo ("<td><b>" . _("Delete organizational unit") . ":</b></td>\n");
-	echo ("<td>&nbsp;</td>\n");
-	echo ("<td><select size=1 name=groupsuff_d>");
-	for ($i = 0; $i < sizeof($grp_units); $i++) {
-		echo ("<option>" . $grp_units[$i] . "</option>\n");
-	}
-	echo ("</select><td>\n");
-	echo ("<td>&nbsp;</td>\n");
-	echo ("<td><a href=\"help.php?HelpNumber=602\" target=\"lamhelp\">". _("Help") ."</a></td>\n");
-	echo ("</tr>\n");
-	echo ("</table>\n");
-	echo ("</fieldset>\n");
-	echo ("<br>\n");
 
 	// host OUs
-	echo ("<fieldset><legend><b>" . _("Samba Hosts") . "</b></legend>\n");
-	echo ("<table border=0>\n");
-	// new OU
-	echo ("<tr>\n");
-	echo ("<td><input type=radio name=\"type\" value=\"new_hst\"></td>\n");
-	echo ("<td><b>" . _("New organizational unit") . ":</b></td>\n");
-	echo ("<td>&nbsp;</td>\n");
-	echo ("<td><select size=1 name=hostsuff_n>");
-	for ($i = 0; $i < sizeof($hst_units); $i++) {
-		echo ("<option>" . $hst_units[$i] . "</option>\n");
+	if ($_SESSION["config"]->get_Suffix('host') != "") {
+		// generate lists of possible suffixes
+		$hst_units = $_SESSION['ldap']->search_units($_SESSION["config"]->get_Suffix('host'));
+		echo ("<fieldset><legend><b>" . _("Samba Hosts") . "</b></legend>\n");
+		echo ("<table border=0>\n");
+		// new OU
+		echo ("<tr>\n");
+		echo ("<td><input type=radio name=\"type\" value=\"new_hst\"></td>\n");
+		echo ("<td><b>" . _("New organizational unit") . ":</b></td>\n");
+		echo ("<td>&nbsp;</td>\n");
+		echo ("<td><select size=1 name=hostsuff_n>");
+		for ($i = 0; $i < sizeof($hst_units); $i++) {
+			echo ("<option>" . $hst_units[$i] . "</option>\n");
+		}
+		echo ("</select><td>\n");
+		echo ("<td><input type=text name=newsuff_h></td>\n");
+		echo ("<td><a href=\"help.php?HelpNumber=601\" target=\"lamhelp\">". _("Help") ."</a></td>\n");
+		echo ("</tr>\n");
+		// delete OU
+		echo ("<tr>\n");
+		echo ("<td><input type=radio name=\"type\" value=\"del_hst\"></td>\n");
+		echo ("<td><b>" . _("Delete organizational unit") . ":</b></td>\n");
+		echo ("<td>&nbsp;</td>\n");
+		echo ("<td><select size=1 name=hostsuff_d>");
+		for ($i = 0; $i < sizeof($hst_units); $i++) {
+			echo ("<option>" . $hst_units[$i] . "</option>\n");
+		}
+		echo ("</select><td>\n");
+		echo ("<td>&nbsp;</td>\n");
+		echo ("<td><a href=\"help.php?HelpNumber=602\" target=\"lamhelp\">". _("Help") ."</a></td>\n");
+		echo ("</tr>\n");
+		echo ("</table>\n");
+		echo ("</fieldset>\n");
+		echo ("<br>\n");
 	}
-	echo ("</select><td>\n");
-	echo ("<td><input type=text name=newsuff_h></td>\n");
-	echo ("<td><a href=\"help.php?HelpNumber=601\" target=\"lamhelp\">". _("Help") ."</a></td>\n");
-	echo ("</tr>\n");
-	// delete OU
-	echo ("<tr>\n");
-	echo ("<td><input type=radio name=\"type\" value=\"del_hst\"></td>\n");
-	echo ("<td><b>" . _("Delete organizational unit") . ":</b></td>\n");
-	echo ("<td>&nbsp;</td>\n");
-	echo ("<td><select size=1 name=hostsuff_d>");
-	for ($i = 0; $i < sizeof($hst_units); $i++) {
-		echo ("<option>" . $hst_units[$i] . "</option>\n");
-	}
-	echo ("</select><td>\n");
-	echo ("<td>&nbsp;</td>\n");
-	echo ("<td><a href=\"help.php?HelpNumber=602\" target=\"lamhelp\">". _("Help") ."</a></td>\n");
-	echo ("</tr>\n");
-	echo ("</table>\n");
-	echo ("</fieldset>\n");
-	echo ("<br>\n");
 
 	// domain OUs
-	if ($_SESSION['config']->is_samba3()) {
+	if ($_SESSION["config"]->get_Suffix('domain') != "") {
+		// generate lists of possible suffixes
+		$dom_units = $_SESSION['ldap']->search_units($_SESSION["config"]->get_Suffix('domain'));
 		echo ("<fieldset><legend><b>" . _("Domains") . "</b></legend>\n");
 		echo ("<table border=0>\n");
 		// new OU
